utcnow — Get the current unixtime in a no-std context

GitHub Workflow Status Crates.io Minimum supported Rust version License

Work in progress.

Supported platforms

  • Dragonfly (untested)
  • Emscripten (untested)
  • FreeBSD
  • iOS (untested)
  • Linux
  • MacOS
  • NetBSD
  • OpenBSD (untested)
  • Redox (untested)
  • WASI
  • wasm32
  • Windows

Structs

Could not query system time

Cannot convert a negative UtcTime, i.e. before 1970-01-01

A Unix time, i.e. seconds since 1970-01-01 in UTC

Constants

true if getting the time is implemented for the target platform

true if utcnow() cannot fail

Functions

Get the current unix time, seconds since 1970-01-01 in UTC

Type Definitions

A result type that default to Error as error type